#!/bin/sh
set -eu

CMD_CHECKER=$(dirname $(readlink -f $0))/iso_fssize_checker
CMD_SYNC=$(dirname $(dirname $(readlink -f $0)))/qakit/prodenv/iso/sync_footprint.py
CMD_PYTHON=python3
WORKDIR=$(mktemp -d /var/tmp/$(basename $0).XXXXXX)
PREVDIR=""
OUTDIR=.
RUN_OPTS=""
RET=0

usage() {
    cat<<EOF
Usage: $(basename $0) [OPTIONS] <iso>

Generate a disk footprint report for a ISO and compare to previous report

Arguments:
  iso   Path to an Ubuntu Desktop ISO

Options:
  -d|--debug        Enable debug mode
  -h|--help         This help
  -D|--directory    Path to output directory
  -P|--previous-directory    Path to previous directory
EOF
    exit 1

}

on_exit() {
    # Cleanup
    [ -d "$WORKDIR" ] && rm -Rf $WORKDIR

    exit $RET
}

trap on_exit EXIT INT QUIT ABRT PIPE TERM

TEMP=$(getopt -o hdD:P: --long help,debug,directory: -- "$@")
eval set -- "$TEMP"

exec 2>&1

while true ; do
    case "$1" in
        -h|--help) 
            usage
            ;;
        -d|--debug)
            set -x
            RUN_OPTS="$RUN_OPTS -d"
            shift ;;
        -D|--directory)
            OUTDIR="$2"
            shift 2 ;;
        -P|--prev)
            PREVDIR="$2"
            shift 2 ;;
        --) shift ; break  ;;
        *) usage;;
    esac
done



ISO=$1

if [ ! -f "$ISO" ]; then
    echo "Error: File does not exist: $ISO"
    exit 1
fi

# FIXME: Not sure why it always exit 1, forcing for the moment
$CMD_CHECKER $RUN_OPTS manifest -o "$WORKDIR" $ISO||true

MANIFEST="$(ls $WORKDIR)"
BUILDID=$(basename $MANIFEST .manifest)
BUILDDIR="$OUTDIR/$BUILDID"

mkdir -p "$BUILDDIR"
mv "$WORKDIR/$MANIFEST" "$BUILDDIR/"
MANIFEST="$BUILDDIR/${BUILDID}.manifest"

if [ ! -d "$PREVDIR" ]; then
    PREVDIR=$OUTDIR
fi

BUILDID_PREV=$(basename $(ls -1 "$PREVDIR/"|grep -B1 -w "$BUILDID"|tail -2|head -1) .manifest)
MANIFEST_PREV="$PREVDIR/$BUILDID_PREV/${BUILDID_PREV}.manifest"

if [ ! -f "$MANIFEST_PREV" ]; then
    BUILDID_PREV=""
    MANIFEST_PREV=""
    echo "Warning: Previous manifest not found"
fi

# FIXME: Not sure why it always exit 1, forcing for the moment
$CMD_CHECKER $RUN_OPTS report -o "$OUTDIR" $MANIFEST $MANIFEST_PREV||true

$CMD_PYTHON $CMD_SYNC $ISO $BUILDDIR

exit $RET
