

function siloLandingsPerWeekChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Total",
                fillColor: translucentGray,
                strokeColor: "Gray",
                pointColor: "Gray",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.total })
            },
            {
                label: "Passed",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.passed }),
            },
            {
                label: "Failed",
                fillColor: translucentRed,
                strokeColor: "Red",
                pointColor: "Red",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.failed }),
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Silo Landings per Week";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function siloPassRatePerWeekChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Pass Rate",
                fillColor: translucentGray,
                strokeColor: "Gray",
                pointColor: "Gray",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.pass_rate.toFixed(1) })
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Silo Pass Rate per Week";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function landingsTable(data, selector) {
    var tableData = data.map(function(obj) {
        return [
	    obj.end,
            obj.week_number,
            obj.total,
            obj.passed,
            obj.failed,
            obj.pass_rate.toFixed(0) + '%',
            (obj.average_time ? obj.average_time : 0).toFixed(1),
            (obj.time_spent_on_failures ? obj.time_spent_on_failures : 0).toFixed(1),
            (obj.cheapest ? obj.cheapest : 0).toFixed(1),
            (obj.most_expensive ? obj.most_expensive : 0).toFixed(1),
        ];
    });
    $(selector).dataTable( {
        data: tableData,
        columns: [
	    { title: 'Ending' },
            { title: 'Week Number' },
            { title: 'Total' },
            { title: 'Passed' },
            { title: 'Failed' },
            { title: 'Pass Rate' },
            { title: 'Average Time' },
            { title: 'Time Spent on Failures' },
            { title: 'Cheapest' },
            { title: 'Most Expensive' },
        ],
    searching: false,
    order: [[0, 'dsc']],
    bDestroy: true,
    });
}

function drawLandingsSection() {
    $.getJSON("./data/landings.json", function(data) {
	    data = data.reverse()
        siloLandingsPerWeekChart(data, "siloLandingsPerWeekChartCanvas");
        siloPassRatePerWeekChart(data, "siloPassRatePerWeekChartCanvas");
        landingsTable(data, "#landingsTable");
    }).fail(function(data, status) {
        console.log("Hiding Landings section");
        $("#landings-section").hide();
        $("#landings-link").hide();
    });
}
