

function manualTestsExecutedPerWeekChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Not Completed",
                fillColor: translucentLimeGreen,
                strokeColor: "LimeGreen",
                pointColor: "LimeGreen",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual_not_completed })
            },
            {
                label: "Blocked",
                fillColor: translucentGold,
                strokeColor: "Gold",
                pointColor: "Gold",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual_blocked })
            },
            {
                label: "Failed",
                fillColor: translucentRed,
                strokeColor: "Red",
                pointColor: "Red",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual_failed })
            },
            {
                label: "Passed",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual_passed })
            },
            {
                label: "Total",
                fillColor: translucentGray,
                strokeColor: "Gray",
                pointColor: "Gray",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual })
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Manual Tests Executed Per Week";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function automatedTestsExecutedPerWeekChartCanvas(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Failed",
                fillColor: translucentRed,
                strokeColor: "Red",
                pointColor: "Red",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.automated_failed })
            },
            {
                label: "Passed",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.automated_passed })
            },
            {
                label: "Total",
                fillColor: translucentGray,
                strokeColor: "Gray",
                pointColor: "Gray",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.automated })
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Automated Tests Executed Per Week";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function manualVsAutomatedChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Automated",
                fillColor: translucentRed,
                strokeColor: "Red",
                pointColor: "Red",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.automated })
            },
            {
                label: "Manual",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual }),
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Manual vs. Automated";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function testExecutionTable(data, selector) {
    var tableData = data.map(function(obj) {
        return [
	    obj.end,
            obj.week_number,
            obj.total,
            obj.manual,
            obj.manual_passed,
            obj.manual_failed,
            obj.manual_blocked,
            obj.manual_not_completed,
            obj.automated,
            obj.automated_passed,
            obj.automated_failed,
            obj.distinct_manual,
            obj.distinct_automated,
        ];
    });
    $(selector).dataTable( {
        data: tableData,
        columns: [
	    { title: 'Ending' },
            { title: 'Week Number' },
            { title: 'Total' },
            { title: 'Manual' },
            { title: 'Manual Passed' },
            { title: 'Manual Failed' },
            { title: 'Manual Blocked' },
            { title: 'Manual Not Completed' },
            { title: 'Automated' },
            { title: 'Automated Passed' },
            { title: 'Automated Failed' },
            { title: 'Distinct Manual' },
            { title: 'Distinct Automated' },
        ],
        searching: false,
        order: [[0, 'dsc']],
        bDestroy: true,
    });
}

function drawTestExecutionSection() {
    $.getJSON("./data/test-execution.json", function(data) {
        data = data.reverse()
        manualTestsExecutedPerWeekChart(
            data, "manualTestsExecutedPerWeekChartCanvas");
        automatedTestsExecutedPerWeekChartCanvas(
            data, "automatedTestsExecutedPerWeekChartCanvas");
        manualVsAutomatedChart(
            data, "manualVsAutomatedChartCanvas");
        testExecutionTable(data, '#testExecutionTable');
    }).fail(function(data, status) {
        console.log("Hiding Test Execution section");
        $("#test-execution-section").hide();
        $("#test-execution-link").hide();
    });
}
