

function testsInLibraryChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Ready",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.ready })
            },
            {
                label: "To Review",
                fillColor: translucentRed,
                strokeColor: "Red",
                pointColor: "Red",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.to_review }),
            },
            {
                label: "Other",
                fillColor: translucentYellow,
                strokeColor: "Gold",
                pointColor: "Gold",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.other_status }),
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Tests in Library";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function automatedVsManualChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Manual Ready",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.manual_ready })
            },
            {
                label: "Automated Ready",
                fillColor: translucentRed,
                strokeColor: "Red",
                pointColor: "Red",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return week.automated_ready }),
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Automated vs. Manual";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function percentageAutomatedChart(data, canvas) {
    var chartData = {
        labels: data.map(function(week) { return week.end }),
        datasets: [
            {
                label: "Percentage Automated",
                fillColor: translucentMediumBlue,
                strokeColor: "MediumBlue",
                pointColor: "MediumBlue",
                pointStrokeColor: "White",
                pointHighlightFill: "White",
                pointHighlightStroke: "Gainsboro",
                data: data.map(function(week) { return (week.percent_automated * 100).toFixed(1) })
            },
        ]
    }
    var ctx = document.getElementById(canvas).getContext("2d");
    var chart = new Chart(ctx).Line(chartData, defaultChartConfig);
    chart.title = "Percent Automated";
    document.getElementById(canvas + "Legend").innerHTML = chart.generateLegend();
}

function testLibraryTable(data, selector) {
    var tableData = data.map(function(obj) {
        return [
	    obj.end,
            obj.week_number,
            obj.total,
            obj.ready,
            obj.to_review,
            obj.other_status,
            obj.manual_ready,
            obj.automated_ready,
            (obj.percent_automated * 100).toFixed(1) + "%",
        ];
    });
    $(selector).dataTable( {
        data: tableData,
        columns: [
	    { title: 'Ending' },
            { title: 'Week Number' },
            { title: 'Total' },
            { title: 'Ready' },
            { title: 'To Review' },
            { title: 'Other' },
            { title: 'Manual Ready' },
            { title: 'Automated Ready' },
            { title: '% Auto' },
        ],
        searching: false,
        order: [[0, 'dsc']],
        bDestroy: true,
    });
}

function drawTestLibrarySection() {
    $.getJSON("./data/test-library.json", function(data) {
	    data = data.reverse()
        testsInLibraryChart(data, "testsInLibraryChartCanvas");
        automatedVsManualChart(data, "automatedVsManualChartCanvas");
        percentageAutomatedChart(data, "percentageAutomatedChartCanvas");
        testLibraryTable(data, "#testLibraryTable");
    }).fail(function(data, status) {
        console.log("Hiding Test Library section");
        $("#test-library-section").hide();
        $("#test-library-link").hide();
    });
}
