# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import hashlib

from launchpadlib.launchpad import Launchpad


class Ppa:

    def __init__(self, name, team):
        self.name = name
        self.team = team

    def get_source_packages(self, status='Published'):
        """
        This method returns from Launchpad, the list of source packages
        included in the ppa. By default, only Published source packages
        are returned
        :param status the source package status to filter the packages
        in the ppa
        :return a list of source packages
        """
        launchpad = Launchpad.login_anonymously('ci job', 'production')
        team = launchpad.people.findTeam(text=self.team)[0]
        archive = team.getPPAByName(name=self.name)
        return archive.getPublishedSources(status=status)

    def calculate_hash(self):
        """
        This method get the list of published source packages in the ppa
        and use their version to calculate a hash which uniquely identify
        the current set of published packages in the ppa
        :return: the hash that identifies the list of packages in the ppa
        """
        src_pkgs = self.get_source_packages()
        versions = ''.join([package.source_package_version for package in src_pkgs])
        return hashlib.md5(versions.encode('utf-8')).hexdigest()
