# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
import logging
import multiprocessing
import time

from qakit.practitest.practitest import practitest_time_to_datetime

logger = logging.getLogger(__name__)


def record_test_history(db, test):
    """Make an entry in our test history, appending the time.

    :param db: a MongoClient collection in which PractiTest data is stored
    :param test: a PractiTest test dict

    """
    db.test_history.insert(
        dict({'datetime': datetime.datetime.now()}, **test))


def update_test(db, practitest_session, test):
    """Update a test from PractiTest, depositing it in our db.

    :param db: a MongoClient collection in which PractiTest data is stored
    :param practitest_session: a PractiTestSession
    :param test: a PractiTest test dict

    """
    logger.debug("Retrieving test {}".format(test['system_id']))
    try:
        test = practitest_session.get_test(test['display_id'])
    except ValueError:
        logger.warn("Test {} not found.".format(test['system_id']))
    # while we're at it make an entry in our test history collection
    record_test_history(db, test)
    db.tests.update(
        {'system_id': test['system_id']},
        test,
        upsert=True)


def update_tests(db, practitest_session):
    """Update our db with all tests from PractiTest.

    :param db: a MongoClient collection in which PractiTest data is stored
    :param practitest_session: a PractiTestSession

    """
    logger.info("Retrieving tests from PractiTest.")
    # get_tests returns a list of tests in brief, with no custom fields
    tests = practitest_session.get_tests()
    # . . . so we have to get each in detail
    for test in tests:
        update_test(db, practitest_session, test)
