#!/usr/bin/python3
# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import datetime
import logging
import sys

import pymongo

import qakit.config as config
import qakit.metrics.practitest.tests as tests
import qakit.metrics.util as util
import qakit.practitest.practitest as practitest

logger = logging.getLogger(__name__)


def update_test_library_data(db, practitest_session):
    """Update PractiTest test library data.

    :param db: a MongoClient database in which PractiTest data is stored
    :param practitest_session: a PractiTestSession

    """
    start = datetime.datetime.now()
    db.test_history_runs.insert({'start': start})
    tests.update_tests(db, practitest_session)
    end = datetime.datetime.now()
    db.test_history_runs.update(
        {'start': start},
        {'start': start,
         'end': end},
        upsert=True)


def main():
    util.setup_logging()
    config_dict = util.read_config(config.get_config_file_location())
    conn = pymongo.MongoClient()
    db = conn.metrics
    practitest_session = practitest.PractitestSession(
        config_dict['project_id'],
        config_dict['api_key'],
        config_dict['api_secret_key'])
    update_test_library_data(db, practitest_session)


if __name__ == '__main__':
    try:
        sys.exit(main())
    except Exception as e:
        logger.error(e, exc_info=True)
