# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest
from unittest import mock

from bson import ObjectId

import qakit.metrics.practitest.instances as instances


INSTANCE = {
    "_id": ObjectId("5590253dca21169c04a38b51"),
    "tester": {
        "value": "iahmad",
        "name": "Tester"
    },
    "last_run_week_number": 20,
    "name": "Complete Edges Intro",
    "last_run": {
        "value": "21-May-2015  20:59",
        "name": "Last Run"
    },
    "___f_10578": {
        "value": None,
        "name": "Build #"
    },
    "id": "10:1",
    "system_id": 1393092,
    "run_status": {
        "value": "FAILED",
        "name": "Run Status"
    }
}


TESTSETS = [
    {'id': 761},
    {'id': 762},
    {'id': 763},
    {'id': 764},
    {'id': 765},
    {'id': 766},
    {'id': 767}
]


class AppendTestSetIdTestCase(unittest.TestCase):

    def test_testset_id_appended_correctly(self):
        instance = instances.append_testset_id(INSTANCE)
        self.assertEqual(10, instance['testset_id'])


class AppendDataToInstanceDictTestCase(unittest.TestCase):

    @mock.patch('qakit.practitest.practitest.append_last_run_datetime')
    @mock.patch('qakit.metrics.practitest.instances.append_testset_id')
    def test_appends_called(self,
                            mock_append_testset_id,
                            mock_append_last_run_datetime):
        # I agree, this should never fail :)
        mock_append_last_run_datetime.return_value = 'fake-instance'
        instances.append_data_to_instance_dict(INSTANCE)
        mock_append_last_run_datetime.assert_called_with(INSTANCE)
        mock_append_testset_id.assert_called_with('fake-instance')


@mock.patch('qakit.metrics.practitest.instances.update_testset_instances')
class UpdateTestSetInstancesTestCase(unittest.TestCase):

    def test_no_testset_ids_specified(self, mock_update_testset_instances):
        db = mock.Mock(
            testsets=mock.Mock(
                find=mock.Mock(return_value=TESTSETS)))
        instances.update_testsets_instances(
            db,
            'fake-practitest-session',
            None)
        self.assertEqual(7, mock_update_testset_instances.call_count)

    def test_one_testset_specified(self, mock_update_testset_instances):
        instances.update_testsets_instances(
            'fake-db',
            'fake-practitest-session',
            [761])
        self.assertEqual(1, mock_update_testset_instances.call_count)
        mock_update_testset_instances.assert_called_with(
            'fake-db', 'fake-practitest-session', 761)

    def test_several_testsets_specified(self, mock_update_testset_instances):
        testset_ids = [761, 762, 763]
        instances.update_testsets_instances(
            'fake-db',
            'fake-practitest-session',
            testset_ids)
        self.assertEqual(3, mock_update_testset_instances.call_count)
        for testset_id in testset_ids:
            mock_update_testset_instances.assert_any_call(
                'fake-db', 'fake-practitest-session', testset_id)
