# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
import unittest
from unittest import mock

from bson import ObjectId

import qakit.metrics.practitest.tests as tests


TEST = {
    "___f_10489": {
        "value": "High",
        "name": "Test Priority"
    },
    "description": "",
    "system_id": 423394,
    "___f_10589": {
        "value": "ubuntu_system_tests.tests.test_tutorial.TutorialTestCase.test_complete_tutorial",
        "name": "External ID"
    },
    "tags": {
        "value": "",
        "name": "Tags (comma separated)"
    },
    "___f_10484": {
        "value": None,
        "name": "Application"
    },
    "author": {
        "value": "iahmad",
        "name": "Author"
    },
    "test_status": {
        "value": "Ready",
        "name": "Status"
    },
    "___f_10476": {
        "value": "[\"Krillin\", \"Mako\", \"Emulator\"]",
        "name": "Devices"
    },
    "created_at": {
        "value": "19-May-2015  22:21",
        "name": "Created"
    },
    "___f_12587": {
        "value": "[\"Phone\"]",
        "name": "ProductType"
    },
    "___f_10474": {
        "value": "[\"UI & Graphics\"]",
        "name": "Test Domain"
    },
    "run_status": {
        "value": "FAILED",
        "name": "Run Status"
    },
    "name": "Complete Edges Intro",
    "___f_10475": {
        "value": "Ubuntu",
        "name": "Image Part"
    },
    "___f_10662": {
        "value": None,
        "name": "LP Bugs"
    },
    "id": 560,
    "last_run": {
        "value": "20-Oct-2015  01:11",
        "name": "Last Run"
    },
    "updated_at": {
        "value": "09-Sep-2015  10:35",
        "name": "Last Modified"
    },
    "___f_10433": {
        "value": "[\"14.10\"]",
        "name": "Release"
    },
    "___f_10665": {
        "value": "no",
        "name": "Automation Backlog"
    },
    "___f_10490": {
        "value": "Sanity",
        "name": "Test Level"
    }
}


class RecordTestHistoryTestCase(unittest.TestCase):

    def test_inserts(self):
        insert = mock.Mock()
        db = mock.Mock(test_history=mock.Mock(insert=insert))
        tests.record_test_history(db, TEST)
        self.assertTrue(insert.called)
