# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest
from unittest import mock

import qakit.metrics.practitest.testsets as testsets

TESTSETS = [
    {'id': 761},
    {'id': 762},
    {'id': 763},
    {'id': 764},
    {'id': 765},
    {'id': 766},
    {'id': 767}
]


class GetLastKnownTestsetIdTestCase(unittest.TestCase):

    def testset_exists(self):
        db = mock.Mock(
            testsets=mock.Mock(
                find=mock.Mock(
                    return_value=mock.Mock(
                        sort=mock.Mock(
                            return_value=mock.Mock(
                                limit=mock.Mock(
                                    return_value=TESTSETS[:1])))))))
        self.assertEqual(
            761,
            testsets._get_last_known_testset_id(db))

    def test_no_testsets_raises_valueerror(self):
        testsets_ = mock.MagicMock()
        get_item = testsets_.sort.return_value.limit.return_value.__getitem__
        get_item.side_effect = IndexError
        db = mock.Mock(
            testsets=mock.Mock(
                find=mock.Mock(
                    return_value=testsets_)))
        with self.assertRaises(ValueError):
            testsets._get_last_known_testset_id(db)


@mock.patch('qakit.metrics.practitest.testsets.retrieve_testset')
class UpdateTestsetsTestCase(unittest.TestCase):

    def test_no_testsets_specified(self, mock_retrieve_testset):
        db = mock.Mock(
            testsets=mock.Mock(
                find=mock.Mock(
                    return_value=TESTSETS)))
        mock_retrieve_testset.return_value = {'n': 1}
        testsets.update_testsets(db, 'fake-practitest-session')
        for testset_id in [testset['id'] for testset in TESTSETS]:
            mock_retrieve_testset.assert_any_call(
                db, 'fake-practitest-session', testset_id)

    def test_testsets_specified(self, mock_retrieve_testset):
        mock_retrieve_testset.return_value = {'n': 1}
        testsets_ = [testset['id'] for testset in TESTSETS]
        testsets.update_testsets('fake-db', 'fake-practitest-session', testsets_)
        for testset_id in [testset['id'] for testset in TESTSETS]:
            mock_retrieve_testset.assert_any_call(
                'fake-db', 'fake-practitest-session', testset_id)
