# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
import unittest
from unittest import mock

import qakit.metrics.reports as reports


class TestIsoWeekday(unittest.TestCase):

    def test_sunday_sanity(self):
        self.assertEqual(
            7, datetime.datetime(2015, 11, 15).isoweekday())


class GetLastIsoWeekStartDatetime(unittest.TestCase):

    def test_wednesday(self):
        self.assertEqual(datetime.datetime(2015, 11, 9),
                         reports.get_last_iso_week_start_datetime(
                             datetime.datetime(2015, 11, 11)))

    def test_monday(self):
        self.assertEqual(datetime.datetime(2015, 11, 9),
                         reports.get_last_iso_week_start_datetime(
                             datetime.datetime(2015, 11, 9)))

    def test_friday(self):
        self.assertEqual(datetime.datetime(2015, 11, 16),
                         reports.get_last_iso_week_start_datetime(
                             datetime.datetime(2015, 11, 20)))


class GetNextIsoWeekStartDatetime(unittest.TestCase):

    def test_wednesday(self):
        self.assertEqual(datetime.datetime(2015, 11, 16),
                         reports.get_next_iso_week_start_datetime(
                             datetime.datetime(2015, 11, 11)))

    def test_monday(self):
        self.assertEqual(datetime.datetime(2015, 11, 16),
                         reports.get_next_iso_week_start_datetime(
                             datetime.datetime(2015, 11, 9)))

    def test_friday(self):
        self.assertEqual(datetime.datetime(2015, 11, 23),
                         reports.get_next_iso_week_start_datetime(
                             datetime.datetime(2015, 11, 20)))


class ComposeWeekSeriesTestCase(unittest.TestCase):

    def test_one_aligned_week(self):
        start = datetime.datetime(2015, 11, 2)
        end = datetime.datetime(2015, 11, 9)
        result = reports.compose_week_series(start, end)
        self.assertEqual([(start, end)], result)

    def test_week_and_a_half(self):
        start = datetime.datetime(2015, 11, 2)
        middle = datetime.datetime(2015, 11, 9)
        end = datetime.datetime(2015, 11, 11)
        result = reports.compose_week_series(start, end)
        self.assertEqual([(start, middle),
                          (middle, end)],
                         result)

    def test_two_aligned_weeks(self):
        start = datetime.datetime(2015, 11, 2)
        middle = datetime.datetime(2015, 11, 9)
        end = datetime.datetime(2015, 11, 16)
        result = reports.compose_week_series(start, end)
        self.assertEqual([(start, middle),
                          (middle, end)],
                         result)

    def test_friday_start(self):
        start = datetime.datetime(2015, 11, 6)
        middle = datetime.datetime(2015, 11, 9)
        end = datetime.datetime(2015, 11, 16)
        result = reports.compose_week_series(start, end)
        self.assertEqual([(start, middle),
                          (middle, end)],
                         result)

    def test_mid_week(self):
        start = datetime.datetime(2015, 11, 10)
        end = datetime.datetime(2015, 11, 12)
        result = reports.compose_week_series(start, end)
        self.assertEqual([(start, end)],
                         result)
