# UESQA Metrics
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest
from unittest import mock

import qakit.metrics.test_execution as test_execution


TESTSETS = [
    {'id': 761},
    {'id': 762},
    {'id': 763},
    {'id': 764},
    {'id': 765},
    {'id': 766},
    {'id': 767}
]


@mock.patch('qakit.metrics.test_execution.update_testsets')
@mock.patch('qakit.metrics.test_execution.update_instances')
class UpdateTestExecutionDataTestCase(unittest.TestCase):

    def test_update_both_testsets_and_instances(
            self,
            mock_update_instances,
            mock_update_testsets):
        test_execution.update_test_execution_data(
            'fake-db', 'fake-practitest-session', 'fake-testset-ids')
        for f in mock_update_instances, mock_update_testsets:
            f.assert_called_with(
                'fake-db',
                'fake-practitest-session',
                testset_ids='fake-testset-ids')


@mock.patch('qakit.metrics.practitest.testsets.update_testsets')
class UpdateTestSetsTestCase(unittest.TestCase):

    def test_testset_ids_specified(self, mock_update_testsets):
        test_execution.update_testsets(
            'fake-db', 'fake-practitest-session', 'fake-testset-ids')
        mock_update_testsets.assert_called_with(
            'fake-db',
            'fake-practitest-session',
            testset_ids='fake-testset-ids')

    @mock.patch('qakit.metrics.practitest.testsets.discover_new_testsets')
    def test_no_testset_ids_specified(
            self,
            mock_discover_new_testsets,
            mock_update_testsets):
        db = mock.Mock(
            testsets=mock.Mock(
                find=mock.Mock(return_value=TESTSETS)))
        test_execution.update_testsets(
            db, 'fake-practitest-session', testset_ids=None)
        mock_discover_new_testsets.assert_called_with(
            db, 'fake-practitest-session')
        testset_ids = [testset['id'] for testset in TESTSETS]
        mock_update_testsets.assert_called_with(
            db, 'fake-practitest-session', testset_ids=testset_ids)


@mock.patch('qakit.metrics.practitest.instances.update_testsets_instances')
class UpdateInstancesTestCase(unittest.TestCase):

    def test_testset_ids_specified(self, mock_update_testsets_instances):
        test_execution.update_instances(
            'fake-db', 'fake-practitest-session', 'fake-testset-ids')
        mock_update_testsets_instances.assert_called_with(
            'fake-db',
            'fake-practitest-session',
            testset_ids='fake-testset-ids')

    def test_no_testset_ids_specified(self, mock_update_testsets_instances):
        db = mock.Mock(
            testsets=mock.Mock(
                find=mock.Mock(return_value=TESTSETS)))
        test_execution.update_instances(db, 'fake-practitest-session', None)
        testset_ids = [testset['id'] for testset in TESTSETS]
        mock_update_testsets_instances.assert_called_with(
            db,
            'fake-practitest-session',
            testset_ids=testset_ids)
