
# PractiSanity
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


def retry(ExceptionToCheck, tries=4, delay=3, backoff=2, logger=None):
    """Retry calling the decorated function using an exponential backoff.

    http://www.saltycrane.com/blog/2009/11/trying-out-retry-decorator-python/
    Original from: http://wiki.python.org/moin/PythonDecoratorLibrary#Retry

    :param ExceptionToCheck: the exception to check. may be a tuple of
        exceptions to check
    :param tries: number of times to try (not retry) before giving up
    :param delay: initial delay between retries in seconds
    :param backoff: backoff multiplier e.g. value of 2 will double the delay
        each retry
    :param logger: logger.Logger to use.
    """
    def deco_retry(f):
        @wraps(f)
        def f_retry(*args, **kwargs):
            for i in range(tries):
                try:
                    return f(*args, **kwargs)
                except ExceptionToCheck as e:
                    d = delay * backoff ** i
                    if logger:
                        logger.warning(
                            "%s, retrying in %d seconds. . . ." % (e, d))
                    time.sleep(d)
            return f(*args, **kwargs)
        return f_retry  # true decorator
    return deco_retry
