
# PractiSubunit
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subunit
import testtools


def parse(filepath):
    """Parse the subunit file at the given path."""
    stream = open(filepath, 'rb')
    stream_result = subunit.ByteStreamToStreamResult(stream)
    result_list = []
    def handle_test(test_dict):
        result_list.append(test_dict)
    dict_result = testtools.StreamToDict(handle_test)
    dict_result.startTestRun()
    try:
        stream_result.run(dict_result)
    finally:
        dict_result.stopTestRun()
    return result_list


def get_subunit_test_by_name(test_name, subunit_results):
    """Returns the named test from the given subunit suite."""
    for result in subunit_results:
        if result['id'] == test_name:
            return result
    return None


def get_log_lines(filepath):
    """ Parse the subunit file at the given path and return all the lines in
    the log details for all the tests
    """
    results = parse(filepath)
    test_logs = []
    for result in results:
        test_log = result['details'].get('test-log')
        if test_log:
            test_logs.append(test_log.as_text().split('\n'))

    log_lines = [line for sublist in test_logs for line in sublist]
    return log_lines
