#!/usr/bin/python3

# PractiSanity
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest
from unittest import mock

from qakit.practitest.practitest import PractitestSession
import qakit.practitest as practitest


TESTS = [
    {'last_run': '09-Feb-2015  11:55',
     'display_id': 6,
     'name': 'adb to locked device',
     'run_status': 'NO RUN',
     'updated_at': '24-Jan-2015  10:16',
     'steps_count': 5,
     'system_id': 362866},
    {'last_run': '09-Feb-2015  11:55',
     'display_id': 7,
     'name': 'adb to unlocked device',
     'run_status': 'NO RUN',
     'updated_at': '24-Jan-2015  10:18',
     'steps_count': 5,
     'system_id': 362867},
    {'last_run': '09-Feb-2015  11:55',
     'display_id': 8,
     'name': 'adb to locked device - shell enabled',
     'run_status': 'NO RUN',
     'updated_at': '24-Jan-2015  10:28',
     'steps_count': 6,
     'system_id': 362868},
    {'last_run': '26-Feb-2015  11:44',
     'display_id': 94,
     'name': ('Complete wizard successfully '
              '(English, SIM inserted, Wi-Fi connected)'),
     'run_status': 'PASSED',
     'updated_at': '25-Feb-2015  16:14',
     'steps_count': 9,
     'system_id': 371857},
    {'run_status': 'FAILED',
     'test_status': 'Ready',
     'display_id': 109,
     'name': 'Discover Bluetooth devices',
     'system_id': 371872,
     'updated_at': '03-Mar-2015  16:07',
     'last_run': '03-Mar-2015  17:22',
     'steps_count': 3},
]


INSTANCES = [
    {'name': ('Complete wizard successfully '
              '(English, SIM inserted, Wi-Fi connected)'),
     'run_status': {'name': 'Run Status', 'value': 'PASSED'},
     'last_run': {'name': 'Last Run', 'value': '27-Feb-2015  00:44'},
     'system_id': 1188312,
     'id': '24:1'},
    {'name': 'Complete Edges Intro',
     'run_status': {'name': 'Run Status', 'value': 'NO RUN'},
     'last_run': {'name': 'Last Run', 'value': ''},
     'system_id': 1188313,
     'id': '24:2'},
    {'name': 'Dual SIMs both register to network',
     'run_status': {'name': 'Run Status', 'value': 'NO RUN'},
     'last_run': {'name': 'Last Run', 'value': ''},
     'system_id': 1188314,
     'id': '24:37'},
    {'name': 'Take photo from front camera',
     'run_status': {'name': 'Run Status', 'value': 'NO RUN'},
     'last_run': {'name': 'Last Run', 'value': ''},
     'system_id': 1188315,
     'id': '24:4'},
    {'name': 'Take photo from rear camera',
     'run_status': {'name': 'Run Status', 'value': 'NO RUN'},
     'last_run': {'name': 'Last Run', 'value': ''},
     'system_id': 1188316,
     'id': '24:5'}
]


TEST = {
    'last_run': {'value': '26-Feb-2015  18:44', 'name': 'Last Run'},
    'name': 'Complete wizard successfully (English, SIM inserted, Wi-Fi connected)',
    'run_status': {'value': 'PASSED', 'name': 'Run Status'},
    '___f_9063': {'value': 'no', 'name': 'Automated'},
    '___f_9061': {'value': '1-High', 'name': 'Priority'},
    '___f_8660': {'value': None, 'name': 'Devices'},
    '___f_9068': {'value': None, 'name': 'Subsystem'},
    '___f_9069': {'value': None, 'name': 'Component'},
    'description': 'This test requires that the Welcome Wizard is enabled. The ideal way to enable the wizard is to reset the device, but if this is not possible you can run phablet-config welcome-wizard --enable and restart lightdm. This is a change',
    'tags': {'value': '', 'name': 'Tags (comma separated)'},
    '___f_9070': {'value': None, 'name': 'Release'},
    '___f_8658': {'value': None, 'name': 'Execution Duration'},
    'system_id': 371857,
    'test_status': {'value': 'Ready', 'name': 'Status'},
    'updated_at': {'value': '25-Feb-2015  23:14', 'name': 'Last Modified'},
    '___f_9136': {'value': None, 'name': 'Pre-requisites and setup'},
    '___f_9062': {'value': '["Sanity"]', 'name': 'Test Level'},
    '___f_9065': {'value': None, 'name': 'Whiteboard'},
    'author': {'value': 'jean-baptiste.lallement@canonical.com',
               'name': 'Author'},
    '___f_9064': {'value': 'ubuntu_sanity_tests.tests.test_settings_wizard.SettingsWizardTestCase.test_complete_settings_wizard',
                  'name': 'External ID'},
    'created_at': {'value': '09-Feb-2015  18:40', 'name': 'Created'},
    'id': 94
}


NOT_SANITY_TEST = {
    'last_run': {'value': '26-Feb-2015  07:06', 'name': 'Last Run'},
    'name': 'Browse to web page and navigate forward and back',
    'run_status': {'value': 'PASSED', 'name': 'Run Status'},
    '___f_9063': {'value': None, 'name': 'Automated'},
    '___f_9061': {'value': '1-High', 'name': 'Priority'},
    '___f_8660': {'value': None, 'name': 'Devices'},
    '___f_9068': {'value': None, 'name': 'Subsystem'},
    '___f_9069': {'value': None, 'name': 'Component'},
    'description': '',
    'tags': {'value': '', 'name': 'Tags (comma separated)'},
    '___f_9070': {'value': None, 'name': 'Release'},
    '___f_8658': {'value': None, 'name': 'Execution Duration'},
    'system_id': 371870,
    'test_status': {'value': 'Ready', 'name': 'Status'},
    'updated_at': {'value': '09-Feb-2015  11:52', 'name': 'Last Modified'},
    '___f_9136': {'value': None, 'name': 'Pre-requisites and setup'},
    '___f_9062': {'value': '["Sanity"]', 'name': 'Test Level'},
    '___f_9065': {'value': None, 'name': 'Whiteboard'},
    'author': {'value': 'jean-baptiste.lallement@canonical.com',
               'name': 'Author'},
    '___f_9064': {'value': None, 'name': 'External ID'},
    'created_at': {'value': '09-Feb-2015  11:40', 'name': 'Created'},
    'id': 107
}


class PractitestSessionTestCase(unittest.TestCase):

    def setUp(self):
        super().setUp()
        self.practitest_session = PractitestSession(
            42, 'fake_api_key', 'fake_api_secret_key')


class GetInstancesTestCase(PractitestSessionTestCase):

    def test_get_instances(self):
        with mock.patch.object(self.practitest_session,
                               '_get') as mock_get:
            result = self.practitest_session.get_instances(24)
        mock_get.assert_called_with(
            'https://prod.practitest.com/api/sets/24/instances.json')


class GetTestsetTestCase(PractitestSessionTestCase):

    def test_get_testset(self):
        with mock.patch.object(self.practitest_session,
                               '_get') as mock_get:
            self.practitest_session.get_testset(42)
        mock_get.assert_called_with(
            'https://prod.practitest.com/api/sets/42.json')


class GetInstancesTestCase(PractitestSessionTestCase):

    def test_get_testset(self):
        with mock.patch.object(self.practitest_session,
                               '_get') as mock_get:
            self.practitest_session.get_instances(42)
        mock_get.assert_called_with(
            'https://prod.practitest.com/api/sets/42/instances.json',
            {'page': 1})


class GetTestTestCase(PractitestSessionTestCase):

    def test_get_test(self):
        with mock.patch.object(self.practitest_session,
                               '_get') as mock_get:
            self.practitest_session.get_test(42)
        mock_get.assert_called_with(
            'https://prod.practitest.com/api/tests/42.json')


class GetTestFromTestsByName(PractitestSessionTestCase):

    def test_get_test_from_tests_by_name(self):
        test = {
            'last_run': '26-Feb-2015  11:44',
            'display_id': 94,
            'name': ('Complete wizard successfully '
                     '(English, SIM inserted, Wi-Fi connected)'),
            'run_status': 'PASSED',
            'updated_at': '25-Feb-2015  16:14',
            'steps_count': 9,
            'system_id': 371857
        }
        test_name = ('Complete wizard successfully '
                     '(English, SIM inserted, Wi-Fi connected)')
        result = self.practitest_session.get_test_from_tests_by_name(
            test_name, TESTS)
        self.assertEqual(test, result)

    def test_get_gibberish(self):
        test_name = 'Test exploding OSK'
        result = self.practitest_session.get_test_from_tests_by_name(
            test_name, TESTS)
        self.assertIsNone(result)


class GetIdOfTestByNameTestCase(PractitestSessionTestCase):

    def test_get_id_of_test_by_name(self):
        with mock.patch.object(
                self.practitest_session,
                'get_test_from_tests_by_name') as get_test_mock:
            get_test_mock.return_value = {
                'last_run': '26-Feb-2015  11:44',
                'display_id': 94,
                'name': ('Complete wizard successfully '
                         '(English, SIM inserted, Wi-Fi connected)'),
                'run_status': 'PASSED',
                'updated_at': '25-Feb-2015  16:14',
                'steps_count': 9,
                'system_id': 371857
            }
            test_name = ('Complete wizard successfully '
                         '(English, SIM inserted, Wi-Fi connected)')
            result = self.practitest_session._get_id_of_test_by_name(
                test_name, TESTS)
        self.assertEqual(94, result)


@unittest.skip
class GetTestExternalId(PractitestSessionTestCase):

    def test_get_test_external_id(self):
        result = practitest.get_test_external_id(TEST)
        self.assertEqual(('ubuntu_sanity_tests.tests.test_settings_wizard.'
                          'SettingsWizardTestCase.test_complete_settings_wizard'),
                         result)

    def test_get_id_of_not_sanity_test(self):
        result = self.practitest_session.get_test_external_id(NOT_SANITY_TEST)
        self.assertEqual(None, result)
