# qakit - tools for UEQA engineers
# Copyright (C) 2014-2015 Canonical
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.


"""Functions for trello integration."""

from __future__ import absolute_import

import requests


class TrelloApi(object):

    def __init__(self, app_key, token):
        self._app_key = app_key
        self._token = token

    def get_boards_list(
            self,
            board_id,
            cards=None,
            card_fields=None,
            filter=None,
            fields=None):
        resp = requests.get(
            "https://trello.com/1/boards/{}/lists".format(board_id),
            params=dict(
                key=self._app_key,
                token=self._token,
                cards=cards,
                card_fields=card_fields,
                filter=filter,
                fields=fields),
            data=None)
        resp.raise_for_status()
        return resp.json()

    def get_boards_card(
            self,
            board_id,
            actions='all',
            attachments=None,
            members=None,
            checkItemStates=None,
            checklists=None,
            filter=None,
            fields=None,
            since=None):
        resp = requests.get(
            "https://trello.com/1/boards/{}/cards".format(board_id),
            params=dict(
                key=self._app_key,
                token=self._token,
                actions=actions,
                attachments=attachments,
                members=members,
                checkItemStates=checkItemStates,
                checklists=checklists,
                filter=filter,
                fields=fields,
                since=since),
            data=None)
        resp.raise_for_status()
        return resp.json()

    def get_boards_action(
            self,
            board_id,
            filter=None,
            fields=None,
            limit=1000,
            trello_format=None,
            since=None,
            page=None,
            idModels=None):
        resp = requests.get(
            "https://trello.com/1/boards/{}/actions".format(board_id),
            params=dict(
                key=self._app_key,
                token=self._token,
                filter=filter,
                fields=fields,
                limit=limit,
                format=trello_format,
                since=since,
                page=page,
                idModels=idModels),
            data=None)
        resp.raise_for_status()
        return resp.json()

    def get_cards_actions(self, card_id, filter=None, since=None):
        """Get actions associated with a card from Trello.

        See https://developers.trello.com/advanced-reference/card#get-1-cards-card-id-or-shortlink-actions  # NOQA

        :param card_id: Trello card ID string
        :param filter: list of action type strings to retrieve, defaults (in
            Trello) to commentCard, updateCard
        :param since: datetime from which to query

        """
        resp = requests.get(
            "https://api.trello.com/1/cards/{}/actions".format(card_id),
            params=dict(
                key=self._app_key,
                token=self._token,
                filter=filter),
            data=None)
        resp.raise_for_status()
        return resp.json()
