#!/usr/bin/env python3
# UEQA Vis
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import pymongo


class JenkinsResults:

    def __init__(self, db):
        self.db = db

    def get_build_test_results(self, job_name, build_number):
        """Query db for test results.

        NOTE that we don't return skipped tests.

        """
        return self.db.tests.find(
            {'job_name': job_name,
             'build_number': build_number,
             'status': {'$ne': 'SKIPPED'}}
        )

    def get_test_result(self, job_name, build_number, test_name):
        """Query db for a single test result."""
        return self.db.tests.find_one(
            {'test_name': test_name,
             'job_name': job_name,
             'build_number': build_number})

    def get_trailing_test_results(self, job_name, test_name, limit=10):
        """Return last 'limit' test_name results."""
        return self.db.tests.find(
            {'test_name': test_name,
             'job_name': job_name,
             'status': {'$ne': 'SKIPPED'}}).sort(
                 'build_number', pymongo.DESCENDING).limit(limit)

    def get_test_names(self, job_name):
        """Get all test names associated with a Jenkins job from db."""
        return self.db.tests.find(
            {'job_name': job_name}).distinct('test_name')

    def get_build_numbers(self, job_name, limit=10):
        """Get all build numbers associated with a Jenkins job from db."""
        build_numbers = sorted(
            self.db.builds.find({'job_name': job_name}).distinct('number'),
            reverse=True,
        )
        return build_numbers[:limit]

    def get_build(self, job_name, build_number):
        """Return a specific build."""
        return self.db.builds.find_one(
            {'job_name': job_name,
             'number': build_number}
        )
