#!/usr/bin/python
"""

Create cards on Trello board for testing requests

"""
# Copyright (C) 2014-2015, Canonical Ltd (http://www.canonical.com/)
#
# Authors:
#    Jean-Baptiste Lallement <jean-baptiste.lallement@canonical.com>
#
# This software is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# This software is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this software.  If not, see <http://www.gnu.org/licenses/>.
#
import re
from urlparse import urlparse
from collections import defaultdict


def get_source_packages(silo_info):
    """ Return a list of source packages from silo_info """
    if not silo_info:
        return "N/A"

    if 'sources' in silo_info:
        if silo_info['sources']:
            return ", ".join(silo_info['sources'])
    if 'mps' in silo_info:
        if silo_info['mps']:
            return ", ".join(silo_info['mps'].keys())
    return "N/A"


def linkify_bugs(text):
    lpurl = "https://launchpad.net/bugs/"
    return re.sub('((?!/)\D)(\d{7})(\D)', '\g<1>[\g<2>](%s\g<2>)\g<3>' % lpurl, text)


def dictify_mps(mpstr):
    """ Transform a string of MPs coming from a landing request into a
    dictionary of the form { src: [[mp_name, mp_link] }
    """
    if not mpstr:
        return {}

    mpdict = defaultdict(list)

    for mp in mpstr.splitlines():
        urltokens = urlparse(mp)
        if not urltokens.path:
            # Skip empty lines
            continue

        (committer, project, mpname) = urltokens.path.split('/')[1:4]
        mpdict[project].append([committer, mpname, mp])

    return mpdict

